const appRootDir = require('app-root-dir');
const gulp = require('gulp');
const del = require('del');
const rollup = require('rollup');
const rollupCommonJS = require('rollup-plugin-commonjs');
const rollupBabel = require('rollup-plugin-babel');
const rollupNodeResolve = require('rollup-plugin-node-resolve');
const stringUtils = require('ember-cli-string-utils');

const basePath = appRootDir.get();
const packageJson = require(basePath + '/package.json');
const packageName = packageJson.name;
const extensionName = packageJson.xethya ? packageJson.xethya.extensionName : undefined;

const namedExports = require('../rollup/named-exports');

if (!extensionName) {
  throw new Error('You must add `{ xethya: { extensionName: "Package" } }` to your package.json');
}

gulp.task('extension:clean', function () {
  return del(basePath + '/dist/**');
});

gulp.task('extension:build', ['extension:clean'], function () {
  return rollup.rollup({
    input: basePath + '/src/extension.js',
    plugins: [
      rollupNodeResolve({
        jsnext: true,
        main: true,
      }),
      rollupCommonJS({
        namedExports: namedExports,
      }),
      rollupBabel({
        exclude: basePath + 'node_modules/**',
        presets: [
          ['env', {
            targets: {
              browsers: ['last 2 versions'],
              node: 'current'
            },
            modules: false,
          }],
        ],
        plugins: [
          'external-helpers',
          'transform-decorators',
          'transform-private-underscore'
        ],
      })
    ]
  }).then(function (bundle) {
    ['es', 'umd'].forEach(function (format) {
      bundle.write({
        file: basePath + '/dist/' + packageName + '.' + format + '.js',
        format: format,
        name: 'Xethya.' + stringUtils.classify(extensionName),
        sourcemap: true,
        exports: 'auto'
      });
    });
  });
});
