const appRootDir = require('app-root-dir');
const gulp = require('gulp');
const Karma = require('karma');
const rollupCommonJS = require('rollup-plugin-commonjs');
const rollupBabel = require('rollup-plugin-babel');
const rollupNodeResolve = require('rollup-plugin-node-resolve');

const basePath = appRootDir.get();
const distFile = basePath + '/' + (require(basePath + '/package.json').main);

const testFiles = basePath + '/test/**/*.spec.js';

const namedExports = require('../rollup/named-exports');

gulp.task('extension:test', function () {
  const preprocessors = {};

  preprocessors[testFiles] = 'rollup';

  const server = new Karma.Server({
    frameworks: [
      'mocha',
      'chai',
      'sinon'
    ],
    files: [
      distFile,
      testFiles,
    ],
    browsers: ['ChromeHeadless'],
    reporters: ['mocha'],
    singleRun: true,
    preprocessors: preprocessors,
    rollupPreprocessor: {
      plugins: [
        rollupNodeResolve({
          jsnext: true,
          main: true,
        }),
        rollupCommonJS({
          namedExports: namedExports,
        }),
        rollupBabel({
          exclude: basePath + 'node_modules/**',
          presets: [
            ['env', {
              targets: {
                browsers: ['last 2 versions'],
                node: 'current'
              },
              modules: false,
            }],
          ],
          plugins: [
            'external-helpers',
            'transform-decorators',
            'transform-private-underscore'
          ],
        })
      ],
      format: 'umd'
    }
  });

  server.start();
});
